==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/csv2xtHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "csvxmlTablւ̕ϊ"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-F*/
#define HFDT "sڂږƂ݂Ȃ"
#define HFDC "csvt@C̈sڂږƂxmlTablẽwb_[Ɏ荞"

/*-a*/
#define FNMT "VږXg"
#define FNMC "Ŏw肵ږXgxmlTablẽwb_[ɓo^"

/*-l*/
#define TITT "^Cg"
#define TITC "Ŏw肵^CgxmlTablẽwb_[ɓo^"

/*-c*/
#define COMT "Rg"
#define COMC "Ŏw肵RgxmlTablẽwb_[ɓo^"

/*-s*/
#define SPCT ""
#define SPCC "eLXg̃Xy[Xǂ̕ɒu邩w肷"

/*-I*/
#define IMPT "C|[gt@C"
#define IMPC "wb_[C|[gÃwb_[xmlTablẽwb_[ɓo^"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "csvxmlTableɕϊ"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
  csv2xt -F -i dat.txt -o rsl.xt\n\
  csv2xt -aڋqR[h,t,i,,z -i dat.txt -o rls.xt\n\
  csv2xt -F -i dat.txt -l Tvf[^ -c }jApɍ쐬 -o rsl.xt\n\
  csv2xt -I header.xt -i dat.txt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "txt2xt,xt2txt,xt2xml,xml2xt"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre3.tar.gz: musashi-core-1.0.4-pre3/help/ja-sjis/csv2xtHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "csvxmlTablւ̕ϊ"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-F*/
#define HFDT "sڂږƂ݂Ȃ"
#define HFDC "csvt@C̈sڂږƂxmlTablẽwb_[Ɏ荞"

/*-a*/
#define FNMT "VږXg"
#define FNMC "Ŏw肵ږXgxmlTablẽwb_[ɓo^"

/*-l*/
#define TITT "^Cg"
#define TITC "Ŏw肵^CgxmlTablẽwb_[ɓo^"

/*-c*/
#define COMT "Rg"
#define COMC "Ŏw肵RgxmlTablẽwb_[ɓo^"

/*-s*/
#define SPCT ""
#define SPCC "eLXg̃Xy[Xǂ̕ɒu邩w肷"

/*-I*/
#define IMPT "C|[gt@C"
#define IMPC "wb_[C|[gÃwb_[xmlTablẽwb_[ɓo^"

/*-f*/
#define FRCT "ڐm[`FbN"
#define FRCC "ڐ̃`FbNȂȂBwb_[̍ڐɍ킹ďB"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "CSV(Comma Separated Value)tH[}bg̃f[^xmlTableɕϊBCSVɂĂ̕W͂ȂÃR}hł͎̂Sz肵ĂB1)ڂ̓J}ŋ؂ĂB2)s͉sŋ؂ĂB3)_uNI[gň͂܂ꂽ񒆂̃J}̓f[^ƂĈB4)3̂ɂĘAQ̃_uNI[ǵA_uNI[gꕶɕϊB܂Xy[X̓ftHgŃA_[XRAɕϊ(-s ŕύX\)B"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
  csv2xt -F -i dat.txt -o rsl.xt\n\
  csv2xt -aڋqR[h,t,i,,z -i dat.txt -o rls.xt\n\
  csv2xt -F -i dat.txt -l Tvf[^ -c }jApɍ쐬 -o rsl.xt\n\
  csv2xt -I header.xt -i dat.txt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xt2csv,txt2xt,xt2txt,xt2xml,xml2xt"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
